@@ -9,7 +9,8 @@ import logging
 
 import click
 
-from swh.core.cli import CONTEXT_SETTINGS, AliasedGroup, swh as swh_cli_group
+from swh.core.cli import CONTEXT_SETTINGS, AliasedGroup
+from swh.core.cli import swh as swh_cli_group
 
 CFG_HELP = """Software Heritage Vault RPC server."""
 
